;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "meep" "20260705.658"
  "Lightweight modal editing."
  '((emacs "30.1"))
  :url "https://codeberg.org/ideasman42/emacs-meep"
  :commit "f3c37e23257a67a8369b545d5bd06a8f5ffec7b5"
  :revdesc "f3c37e23257a"
  :keywords '("convenience" "modal-editing")
  :authors '(("Campbell Barton" . "ideasman42@gmail.com"))
  :maintainers '(("Campbell Barton" . "ideasman42@gmail.com")))
