;;; meep-preset-php-mode.el --- Meep preset for `php-mode' -*- lexical-binding: t -*-

;;;###autoload
(defun meep-preset-php-mode ()
  "Return the meep preset alist for `php-mode'."
  (declare (important-return-value t))
  (list
   (cons
    'meep-bounds-for-inner-comment
    '(meep-bounds-inner-from-delimiters
      (("/*" . "*/") ; Block comment.
       ("//" . "")))))) ; Line comment.

(provide 'meep-preset-php-mode)
;; Local Variables:
;; fill-column: 99
;; indent-tabs-mode: nil
;; package-lint-main-file: "meep.el"
;; End:
;;; meep-preset-php-mode.el ends here
